@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -56,11 +56,7 @@ struct ofono_call_barring {
 	int ss_req_type;
 	int ss_req_cls;
 	int ss_req_lock;
-	struct ofono_ssn *ssn;
 	struct ofono_ussd *ussd;
-	unsigned int incoming_bar_watch;
-	unsigned int outgoing_bar_watch;
-	unsigned int ssn_watch;
 	unsigned int ussd_watch;
 	const struct ofono_call_barring_driver *driver;
 	void *driver_data;
@@ -385,7 +381,7 @@ static gboolean cb_ss_control(int type, const char *sc,
 		type, sc, sia, sib, sic, dn);
 
 	fac = cb_ss_service_to_fac(sc);
-	if (!fac)
+	if (fac == NULL)
 		return FALSE;
 
 	cb_set_query_bounds(cb, fac, type == SS_CONTROL_TYPE_QUERY);
@@ -402,7 +398,7 @@ static gboolean cb_ss_control(int type, const char *sc,
 	if (strlen(dn) > 0)
 		goto bad_format;
 
-	if (type != SS_CONTROL_TYPE_QUERY && !is_valid_pin(sia, PIN_TYPE_NET))
+	if (type != SS_CONTROL_TYPE_QUERY && !__ofono_is_valid_net_pin(sia))
 		goto bad_format;
 
 	switch (type) {
@@ -419,7 +415,7 @@ static gboolean cb_ss_control(int type, const char *sc,
 		break;
 	}
 
-	if (!operation) {
+	if (operation == NULL) {
 		reply = __ofono_error_not_implemented(msg);
 		g_dbus_send_message(conn, reply);
 
@@ -521,10 +517,10 @@ static gboolean cb_ss_passwd(const char *sc,
 	else
 		fac = cb_ss_service_to_fac(sc);
 
-	if (!fac)
+	if (fac == NULL)
 		return FALSE;
 
-	if (!is_valid_pin(old, PIN_TYPE_NET) || !is_valid_pin(new, PIN_TYPE_NET))
+	if (!__ofono_is_valid_net_pin(old) || !__ofono_is_valid_net_pin(new))
 		goto bad_format;
 
 	cb->pending = dbus_message_ref(msg);
@@ -618,7 +614,7 @@ static void cb_get_properties_reply(struct ofono_call_barring *cb, int mask)
 		ofono_error("Generating a get_properties reply with no cache");
 
 	reply = dbus_message_new_method_return(cb->pending);
-	if (!reply)
+	if (reply == NULL)
 		return;
 
 	dbus_message_iter_init_append(reply, &iter);
@@ -678,7 +674,7 @@ static DBusMessage *cb_get_properties(DBusConnection *conn, DBusMessage *msg,
 	if (__ofono_call_barring_is_busy(cb) || __ofono_ussd_is_busy(cb->ussd))
 		return __ofono_error_busy(msg);
 
-	if (!cb->driver->query)
+	if (cb->driver->query == NULL)
 		return __ofono_error_not_implemented(msg);
 
 	cb->pending = dbus_message_ref(msg);
@@ -862,11 +858,11 @@ static DBusMessage *cb_set_property(DBusConnection *conn, DBusMessage *msg,
 			return __ofono_error_invalid_args(msg);
 
 		dbus_message_iter_get_basic(&iter, &passwd);
-		if (!is_valid_pin(passwd, PIN_TYPE_NET))
+		if (!__ofono_is_valid_net_pin(passwd))
 			return __ofono_error_invalid_format(msg);
 	}
 
-	if (!cb->driver->set)
+	if (cb->driver->set == NULL)
 		return __ofono_error_not_implemented(msg);
 
 	cb_set_query_bounds(cb, cb_locks[lock].fac, FALSE);
@@ -899,7 +895,7 @@ static DBusMessage *cb_disable_all(DBusConnection *conn, DBusMessage *msg,
 	struct ofono_call_barring *cb = data;
 	const char *passwd;
 
-	if (!cb->driver->set)
+	if (cb->driver->set == NULL)
 		return __ofono_error_not_implemented(msg);
 
 	if (__ofono_call_barring_is_busy(cb) || __ofono_ussd_is_busy(cb->ussd))
@@ -909,7 +905,7 @@ static DBusMessage *cb_disable_all(DBusConnection *conn, DBusMessage *msg,
 					DBUS_TYPE_INVALID) == FALSE)
 		return __ofono_error_invalid_args(msg);
 
-	if (!is_valid_pin(passwd, PIN_TYPE_NET))
+	if (!__ofono_is_valid_net_pin(passwd))
 		return __ofono_error_invalid_format(msg);
 
 	cb_set_query_bounds(cb, fac, FALSE);
@@ -946,7 +942,7 @@ static DBusMessage *cb_set_passwd(DBusConnection *conn, DBusMessage *msg,
 	const char *old_passwd;
 	const char *new_passwd;
 
-	if (!cb->driver->set_passwd)
+	if (cb->driver->set_passwd == NULL)
 		return __ofono_error_not_implemented(msg);
 
 	if (__ofono_call_barring_is_busy(cb) || __ofono_ussd_is_busy(cb->ussd))
@@ -957,10 +953,10 @@ static DBusMessage *cb_set_passwd(DBusConnection *conn, DBusMessage *msg,
 					DBUS_TYPE_INVALID) == FALSE)
 		return __ofono_error_invalid_args(msg);
 
-	if (!is_valid_pin(old_passwd, PIN_TYPE_NET))
+	if (!__ofono_is_valid_net_pin(old_passwd))
 		return __ofono_error_invalid_format(msg);
 
-	if (!is_valid_pin(new_passwd, PIN_TYPE_NET))
+	if (!__ofono_is_valid_net_pin(new_passwd))
 		return __ofono_error_invalid_format(msg);
 
 	cb->pending = dbus_message_ref(msg);
@@ -987,41 +983,10 @@ static GDBusMethodTable cb_methods[] = {
 };
 
 static GDBusSignalTable cb_signals[] = {
-	{ "IncomingBarringInEffect",	"" },
-	{ "OutgoingBarringInEffect",	"" },
 	{ "PropertyChanged",		"sv" },
 	{ }
 };
 
-static void call_barring_incoming_enabled_notify(int idx, void *userdata)
-{
-	struct ofono_call_barring *cb = userdata;
-	DBusConnection *conn = ofono_dbus_get_connection();
-	const char *path = __ofono_atom_get_path(cb->atom);
-
-	g_dbus_emit_signal(conn, path, OFONO_CALL_BARRING_INTERFACE,
-			"IncomingBarringInEffect", DBUS_TYPE_INVALID);
-}
-
-static void call_barring_outgoing_enabled_notify(int idx, void *userdata)
-{
-	struct ofono_call_barring *cb = userdata;
-	DBusConnection *conn = ofono_dbus_get_connection();
-	const char *path = __ofono_atom_get_path(cb->atom);
-	DBusMessage *signal;
-
-	signal = dbus_message_new_signal(path, OFONO_CALL_BARRING_INTERFACE,
-						"OutgoingBarringInEffect");
-
-	if (!signal) {
-		ofono_error("Unable to allocate new %s.OutgoingBarringInEffect"
-				" signal", OFONO_CALL_BARRING_INTERFACE);
-		return;
-	}
-
-	g_dbus_send_message(conn, signal);
-}
-
 int ofono_call_barring_driver_register(const struct ofono_call_barring_driver *d)
 {
 	DBG("driver: %p, name: %s", d, d->name);
@@ -1029,7 +994,7 @@ int ofono_call_barring_driver_register(const struct ofono_call_barring_driver *d
 	if (d->probe == NULL)
 		return -EINVAL;
 
-	g_drivers = g_slist_prepend(g_drivers, (void *)d);
+	g_drivers = g_slist_prepend(g_drivers, (void *) d);
 
 	return 0;
 }
@@ -1038,7 +1003,7 @@ void ofono_call_barring_driver_unregister(const struct ofono_call_barring_driver
 {
 	DBG("driver: %p, name: %s", d, d->name);
 
-	g_drivers = g_slist_remove(g_drivers, (void *)d);
+	g_drivers = g_slist_remove(g_drivers, (void *) d);
 }
 
 static void call_barring_unregister(struct ofono_atom *atom)
@@ -1054,14 +1019,6 @@ static void call_barring_unregister(struct ofono_atom *atom)
 	if (cb->ussd)
 		cb_unregister_ss_controls(cb);
 
-	if (cb->incoming_bar_watch)
-		__ofono_ssn_mo_watch_remove(cb->ssn, cb->incoming_bar_watch);
-	if (cb->outgoing_bar_watch)
-		__ofono_ssn_mt_watch_remove(cb->ssn, cb->outgoing_bar_watch);
-
-	if (cb->ssn_watch)
-		__ofono_modem_remove_atom_watch(modem, cb->ssn_watch);
-
 	if (cb->ussd_watch)
 		__ofono_modem_remove_atom_watch(modem, cb->ussd_watch);
 }
@@ -1075,7 +1032,7 @@ static void call_barring_remove(struct ofono_atom *atom)
 	if (cb == NULL)
 		return;
 
-	if (cb->driver && cb->driver->remove)
+	if (cb->driver != NULL && cb->driver->remove != NULL)
 		cb->driver->remove(cb);
 
 	g_free(cb);
@@ -1116,29 +1073,6 @@ struct ofono_call_barring *ofono_call_barring_create(struct ofono_modem *modem,
 	return cb;
 }
 
-static void ssn_watch(struct ofono_atom *atom,
-			enum ofono_atom_watch_condition cond, void *data)
-{
-	struct ofono_call_barring *cb = data;
-
-	if (cond == OFONO_ATOM_WATCH_CONDITION_UNREGISTERED) {
-		cb->ssn = NULL;
-		cb->incoming_bar_watch = 0;
-		cb->outgoing_bar_watch = 0;
-		return;
-	}
-
-	cb->ssn = __ofono_atom_get_data(atom);
-
-	cb->incoming_bar_watch =
-		__ofono_ssn_mo_watch_add(cb->ssn, SS_MO_INCOMING_BARRING,
-				call_barring_incoming_enabled_notify, cb, NULL);
-
-	cb->outgoing_bar_watch =
-		__ofono_ssn_mo_watch_add(cb->ssn, SS_MO_OUTGOING_BARRING,
-				call_barring_outgoing_enabled_notify, cb, NULL);
-}
-
 static void ussd_watch(struct ofono_atom *atom,
 			enum ofono_atom_watch_condition cond, void *data)
 {
@@ -1158,8 +1092,6 @@ void ofono_call_barring_register(struct ofono_call_barring *cb)
 	DBusConnection *conn = ofono_dbus_get_connection();
 	const char *path = __ofono_atom_get_path(cb->atom);
 	struct ofono_modem *modem = __ofono_atom_get_modem(cb->atom);
-	struct ofono_atom *ssn_atom;
-	struct ofono_atom *ussd_atom;
 
 	if (!g_dbus_register_interface(conn, path,
 					OFONO_CALL_BARRING_INTERFACE,
@@ -1173,24 +1105,10 @@ void ofono_call_barring_register(struct ofono_call_barring *cb)
 
 	ofono_modem_add_interface(modem, OFONO_CALL_BARRING_INTERFACE);
 
-	cb->ssn_watch = __ofono_modem_add_atom_watch(modem, OFONO_ATOM_TYPE_SSN,
-					ssn_watch, cb, NULL);
-
-	ssn_atom = __ofono_modem_find_atom(modem, OFONO_ATOM_TYPE_SSN);
-
-	if (ssn_atom && __ofono_atom_get_registered(ssn_atom))
-		ssn_watch(ssn_atom, OFONO_ATOM_WATCH_CONDITION_REGISTERED, cb);
-
 	cb->ussd_watch = __ofono_modem_add_atom_watch(modem,
 					OFONO_ATOM_TYPE_USSD,
 					ussd_watch, cb, NULL);
 
-	ussd_atom = __ofono_modem_find_atom(modem, OFONO_ATOM_TYPE_USSD);
-
-	if (ussd_atom && __ofono_atom_get_registered(ussd_atom))
-		ussd_watch(ussd_atom, OFONO_ATOM_WATCH_CONDITION_REGISTERED,
-				cb);
-
 	__ofono_atom_register(cb->atom, call_barring_unregister);
 }
 
